import { iRect, Rect } from '../../../../../../../../../../../../../rect';
import { eAuthenticity, eCheckDiagnose, eCheckResult } from '../../../../../../../../../../../../../../../consts';
/**
* Structure serves for storing the result of checking of one fluorescent fibers
* type for UV light image. When there is no error.
*/
export interface iFibersType {
    /**
    * Type of the performed check
    * @type {eAuthenticity.UV_FIBERS}
    */
    Type: eAuthenticity.UV_FIBERS;
    /**
    * Element responsible for the results of the checks
    * @type {eCheckResult}
    */
    ElementResult: eCheckResult;
    /**
    * Element with which errors are checked
    * @type {eCheckDiagnose}
    */
    ElementDiagnose: eCheckDiagnose;
    /**
    * Number of RectArray, Width, Length, Area items
    * @type {number}
    */
    RectCount: number;
    /**
    * Coordinates of located areas for defined fibers type
    * @type {iRect[]}
    */
    RectArray: iRect[];
    /**
    * Fibers’ width value for RectArray areas (in pixels)
    * @type {number[]}
    */
    Width: number[];
    /**
    * Fibers’ length value for RectArray areas (in pixels)
    * @type {number[]}
    */
    Length: number[];
    /**
    * Fibers’ area value for RectArray areas (in pixels)
    * @type {number[]}
    */
    Area: number[];
    /**
    * Fibers’ color (B, G, R)
    * @type {number[]}
    */
    ColorValues: number[];
    /**
    * Expected fibers number
    * @type {number}
    */
    ExpectedCount: number;
}
/**
* Structure serves for storing the result of checking of one fluorescent fibers
* type for UV light image. When there is no error.
*/
export declare class FibersType implements iFibersType {
    /**
    * Type of the performed check
    * @type {eAuthenticity.UV_FIBERS | eAuthenticity.UV_BACKGROUND}
    */
    Type: eAuthenticity.UV_FIBERS;
    /**
    * Element responsible for the results of the checks
    * @type {eCheckResult}
    */
    ElementResult: eCheckResult;
    /**
    * Element with which errors are checked
    * @type {eCheckDiagnose}
    */
    ElementDiagnose: eCheckDiagnose;
    /**
    * Number of RectArray, Width, Length, Area items
    * @type {number}
    */
    RectCount: number;
    /**
    * Coordinates of located areas for defined fibers type
    * @type {Rect[]}
    */
    RectArray: Rect[];
    /**
    * Fibers’ width value for RectArray areas (in pixels)
    * @type {number[]}
    */
    Width: number[];
    /**
    * Fibers’ length value for RectArray areas (in pixels)
    * @type {number[]}
    */
    Length: number[];
    /**
    * Fibers’ area value for RectArray areas (in pixels)
    * @type {number[]}
    */
    Area: number[];
    /**
    * Fibers’ color (B, G, R)
    * @type {number[]}
    */
    ColorValues: number[];
    /**
    * Expected fibers number
    * @type {number}
    */
    ExpectedCount: number;
    /**
    * Creates an instance of FibersTypeElement.
    * @param {iFibersType} input - plain object
    * @returns {FibersType}
    */
    static fromPlain: (input: unknown) => FibersType;
    /**
    * Check if the given instance of FibersTypeElement is valid
    * @throws {DocReaderTypeError}
    * @param {FibersType} input - instance of FibersTypeElement to be checked
    * @returns {true | never}
    */
    static validate: (input: FibersType) => true | never;
}
