import { ValidationError } from 'class-validator';
import { AllowPrimitives } from '../../../../types';
import { iRDocumentBarcodeField, RDocumentBarcodeField } from './document-barcode-field.model';
/**
* Used for storing document barcode.
*/
export interface iRDocumentBarcode {
    /**
    * Page index of the document where the barcode was found
    * @type {number}
    */
    pageIndex: number;
    /**
    * Array of barcode fields
    * @type {iRDocumentBarcodeField[]}
    */
    fields: iRDocumentBarcodeField[];
}
/**
* Used for storing document barcode.
*/
export declare class RDocumentBarcode implements iRDocumentBarcode {
    /**
    * Page index of the document where the barcode was found
    * @type {number}
    */
    pageIndex: number;
    /**
    * Array of barcode fields
    * @type {RDocumentBarcodeField[]}
    */
    fields: RDocumentBarcodeField[];
    /**
    * Creates an instance of RDocumentBarcode.
    * @param {AllowPrimitives<iRDocumentBarcode>} input - plain object
    * @returns {RDocumentBarcode}
    */
    static fromPlain: (input: AllowPrimitives<iRDocumentBarcode>) => RDocumentBarcode;
    /**
    * Gets validation errors of RDocumentBarcode
    * @param {RDocumentBarcode} input - input data
    * @returns {ValidationError[]} - array of validation errors
    */
    static getValidationErrors: (input: RDocumentBarcode) => ValidationError[];
    /**
    * Validates RDocumentBarcode
    * @param {RDocumentBarcode[] | RDocumentBarcode} input - input data
    * @returns {boolean} - true if input data is valid
    */
    static isValid: (input: RDocumentBarcode[] | RDocumentBarcode) => boolean;
}
